@@ -65,10 +65,12 @@ class RoborockStateCode(RoborockEnum):
     segment_cleaning = 18
     emptying_the_bin = 22  # on s7+
     washing_the_mop = 23  # on a46
+    washing_the_mop_2 = 25
     going_to_wash_the_mop = 26  # on a46
     in_call = 28
     mapping = 29
     egg_attack = 30
+    patrol = 32
     charging_complete = 100
     device_offline = 101
     locked = 103
@@ -126,6 +128,7 @@ class RoborockErrorCode(RoborockEnum):
     side_brush_error = 17
     fan_error = 18
     dock = 19  # Dock not connected to power
+    optical_flow_sensor_dirt = 20
     vertical_bumper_pressed = 21
     dock_locator_error = 22
     return_to_dock_fail = 23
@@ -150,7 +153,14 @@ class RoborockErrorCode(RoborockEnum):
     clear_brush_exception_2 = 43  # Positioning button error
     filter_screen_exception = 44  # Clean the dock water filter
     mopping_roller_2 = 45  # Wash roller may be jammed
+    up_water_exception = 48
+    drain_water_exception = 49
     temperature_protection = 51  # Unit temperature protection
+    clean_carousel_exception = 52
+    clean_carousel_water_full = 53
+    water_carriage_drop = 54
+    check_clean_carouse = 55
+    audio_error = 56
 
 
 class RoborockFanPowerCode(RoborockEnum):
@@ -236,6 +246,14 @@ class RoborockFanSpeedP10(RoborockFanPowerCode):
     max_plus = 108
 
 
+class RoborockFanSpeedS8MaxVUltra(RoborockFanPowerCode):
+    off = 105
+    balanced = 102
+    custom = 106
+    max_plus = 108
+    smart_mode = 110
+
+
 class RoborockMopModeCode(RoborockEnum):
     """Describes the mop mode of the vacuum cleaner."""
 
@@ -257,6 +275,15 @@ class RoborockMopModeS8ProUltra(RoborockMopModeCode):
     custom = 302
 
 
+class RoborockMopModeS8MaxVUltra(RoborockMopModeCode):
+    standard = 300
+    deep = 301
+    deep_plus = 303
+    fast = 304
+    deep_plus_pearl = 305
+    smart_mode = 306
+
+
 class RoborockMopIntensityCode(RoborockEnum):
     """Describes the mop intensity of the vacuum cleaner."""
 
@@ -292,6 +319,14 @@ class RoborockMopIntensityP10(RoborockMopIntensityCode):
     custom_water_flow = 207
 
 
+class RoborockMopIntensityS8MaxVUltra(RoborockMopIntensityCode):
+    off = 200
+    low = 201
+    medium = 202
+    smart_mode = 209
+    custom_water_flow = 207
+
+
 class RoborockMopIntensityS5Max(RoborockMopIntensityCode):
     """Describes the mop intensity of the vacuum cleaner."""
 
@@ -321,6 +356,7 @@ class RoborockDockErrorCode(RoborockEnum):
     duct_blockage = 34
     water_empty = 38
     waste_water_tank_full = 39
+    maintenance_brush_jammed = 42
     dirty_tank_latch_open = 44
     no_dustbin = 46
     cleaning_tank_full_or_blocked = 53
@@ -335,6 +371,7 @@ class RoborockDockTypeCode(RoborockEnum):
     s7_max_ultra_dock = 6
     s8_dock = 7
     p10_dock = 8
+    s8_maxv_ultra_dock = 10
 
 
 class RoborockDockDustCollectionModeCode(RoborockEnum):
@@ -450,3 +487,138 @@ class DyadError(RoborockEnum):
     dirty_charging_contacts = 10007  # Disconnection between the device and dock. Wipe charging contacts.
     low_battery = 20017  # Low battery level. Charge before starting self-cleaning.
     battery_under_10 = 20018  # Charge until the battery level exceeds 10% before manually starting self-cleaning.
+
+
+class ZeoMode(RoborockEnum):
+    wash = 1
+    wash_and_dry = 2
+    dry = 3
+
+
+class ZeoState(RoborockEnum):
+    standby = 1
+    weighing = 2
+    soaking = 3
+    washing = 4
+    rinsing = 5
+    spinning = 6
+    drying = 7
+    cooling = 8
+    under_delay_start = 9
+    done = 10
+
+
+class ZeoProgram(RoborockEnum):
+    standard = 1
+    quick = 2
+    sanitize = 3
+    wool = 4
+    air_refresh = 5
+    custom = 6
+    bedding = 7
+    down = 8
+    silk = 9
+    rinse_and_spin = 10
+    spin = 11
+    down_clean = 12
+    baby_care = 13
+    anti_allergen = 14
+    sportswear = 15
+    night = 16
+    new_clothes = 17
+    shirts = 18
+    synthetics = 19
+    underwear = 20
+    gentle = 21
+    intensive = 22
+    cotton_linen = 23
+    season = 24
+    warming = 25
+    bra = 26
+    panties = 27
+    boiling_wash = 28
+    socks = 30
+    towels = 31
+    anti_mite = 32
+    exo_40_60 = 33
+    twenty_c = 34
+    t_shirts = 35
+    stain_removal = 36
+
+
+class ZeoSoak(RoborockEnum):
+    normal = 0
+    low = 1
+    medium = 2
+    high = 3
+    max = 4
+
+
+class ZeoTemperature(RoborockEnum):
+    normal = 1
+    low = 2
+    medium = 3
+    high = 4
+    max = 5
+    twenty_c = 6
+
+
+class ZeoRinse(RoborockEnum):
+    none = 0
+    min = 1
+    low = 2
+    mid = 3
+    high = 4
+    max = 5
+
+
+class ZeoSpin(RoborockEnum):
+    none = 1
+    very_low = 2
+    low = 3
+    mid = 4
+    high = 5
+    very_high = 6
+    max = 7
+
+
+class ZeoDryingMode(RoborockEnum):
+    none = 0
+    quick = 1
+    iron = 2
+    store = 3
+
+
+class ZeoDetergentType(RoborockEnum):
+    empty = 0
+    low = 1
+    medium = 2
+    high = 3
+
+
+class ZeoSoftenerType(RoborockEnum):
+    empty = 0
+    low = 1
+    medium = 2
+    high = 3
+
+
+class ZeoError(RoborockEnum):
+    none = 0
+    refill_error = 1
+    drain_error = 2
+    door_lock_error = 3
+    water_level_error = 4
+    inverter_error = 5
+    heating_error = 6
+    temperature_error = 7
+    communication_error = 10
+    drying_error = 11
+    drying_error_e_12 = 12
+    drying_error_e_13 = 13
+    drying_error_e_14 = 14
+    drying_error_e_15 = 15
+    drying_error_e_16 = 16
+    drying_error_water_flow = 17  # Check for normal water flow
+    drying_error_restart = 18  # Restart the washer and try again
+    spin_error = 19  # re-arrange clothes
